#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store
version:              0.7.20
visibility:           public
id:                   store-0.7.20-4fvEGwGgSO24IPEMsF9kfE
key:                  store-0.7.20-4fvEGwGgSO24IPEMsF9kfE
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/mgsloan/store#readme
synopsis:             Fast binary serialization
category:             Serialization, Data
abi:                  3174677c8d78479ab2ad2a13b721ba52
exposed:              True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer

hidden-modules:       Data.Store.Impl
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-0.7.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store
hs-libraries:         HSstore-0.7.20-4fvEGwGgSO24IPEMsF9kfE
depends:
    array-0.5.6.0 async-2.2.6-BOzBj9OU2RsBdXVaxuDTSw base-4.18.2.1
    base-orphans-0.9.4-F93g79l8c15JRU0CelkMYu
    base64-bytestring-1.2.1.0-LOSDeSQSndy1Y93aTSzs7h
    bifunctors-5.6.3-JxqVPFA87CgGZDQtN7CDR0 bytestring-0.11.5.3
    containers-0.6.7 contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha1-0.11.101.0-5rgQ98jSKHzCY2QD3wsBJS deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    free-5.2-3eV35pdiGLABxiaEdhFf3x ghc-prim-0.10.0
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    hspec-2.11.7-CwFT1rdaRmD8UT6wQfam3L
    hspec-smallcheck-0.5.3-2ixF7uHWyhkDOibORaabPg integer-gmp-1.1
    lifted-base-0.2.3.12-3GCXyohS31NLrjL2Vc8r9u
    monad-control-1.0.3.1-B6eCGMg4BOZKbaBZ86kHds
    mono-traversable-1.0.21.0-DU0Sp6b1crZGSIhroYmYCf
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    primitive-0.9.1.0-IuEzc1i7B8w72ArTAK2GO5
    resourcet-1.3.0-HYdPrsWCzneJIcOsQDIVse
    safe-0.3.21-Bi0eBD0gemq14I72arTwzC
    smallcheck-1.2.2-6mpe73Y7FfOBCsEKQ2x1CC
    store-core-0.4.4.7-GdaET75Oram9DGhpG1HKNN
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    th-lift-instances-0.1.20-DQ6wl7ibJJKHOpexOEAKT8
    th-orphans-0.13.17-DBzbOLdnBucKtSugq1W5ic
    th-reify-many-0.1.10-8Nvnir9UCWY1kL1Paof88g
    th-utilities-0.2.5.2-5GbaRr3ye7QE6Sv8pol3AS time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:   /usr/share/doc/haskell-store/html/store.haddock
haddock-html:         /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

